@@ -117,10 +117,9 @@ na.action = c("level", "exclude","lowest")[1], collapse.by.var = FALSE, estimand
 							pval <- NA
 							}
 					}
-			}
-
-		else pval <- 1- .C("psmirnov2x", p = as.double(ks), as.integer(ess[2]), as.integer(ess[1]), PACKAGE = "twang")$p
+		}
 		
+		else pval <- 1- .Call("pSmirnov2x", as.double(ks), as.integer(ess[2]), as.integer(ess[1]))
 		
 		if((sum(is.na(design$variables$x)) > 0) && (na.action == "level") && !isFactor){
 			work <- design$variables
